"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Deploys library contract by saving both in truffle artifacts and deployment coordinator
 * @param coordinator deployment coordinator
 * @param deployerAccount deployer account
 * @param writeKeys write key values for deployment process
 * @param options additional options
 */
function deployLibrary(coordinator, deployerAccount, writeKeys, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const context = coordinator.mainContext();
        context.logger.group(`deploy: ${writeKeys.library}`);
        const LibraryContract = context.artifacts.require((options.libraryName)); /*  as TruffleContract<any>; */
        const lib = yield context.getOrRedeployContractAsync(writeKeys.library, LibraryContract, () => __awaiter(this, void 0, void 0, function* () {
            yield context.deployer.deploy(LibraryContract, {
                from: deployerAccount
            });
            return LibraryContract.deployed();
        }), { redeploy: options.redeploy });
        LibraryContract.address = lib.address;
        // TODO: use normal typing
        // if this object exists than we are inside tests/exec
        // otherwise we are in deployment process
        const resolver = context.artifacts.options;
        if (resolver) {
            yield resolver.artifactor.save(LibraryContract);
        }
        context.logger.groupEnd();
        return lib.address;
    });
}
exports.deployLibrary = deployLibrary;
