"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Performs bitwise AND operation with two numbers
 * @param source op1
 * @param target op2
 * @return binary string of size 32 bytes (256 symbols length)
 */
function bitAND(source, target) {
    const binarySource = Buffer.from(pad(source.toString(2), 256));
    const binaryTarget = Buffer.from(pad(target.toString(2), 256));
    const outBuffer = Buffer.allocUnsafe(256);
    outBuffer.fill(0);
    for (let sourceIdx = 0; sourceIdx < binarySource.length; ++sourceIdx) {
        outBuffer.writeUInt8(binarySource.readUInt8(sourceIdx) &
            binaryTarget.readUInt8(sourceIdx), sourceIdx);
    }
    return outBuffer.toString();
}
exports.bitAND = bitAND;
/**
 * Checks if target number has binary flags from flag
 * @param target target number to check
 * @param flag flag number that is required to have
 */
function hasFlag(target, flag) {
    const binaryFlag = pad(flag.toString(2), 256);
    return bitAND(flag, target) === binaryFlag;
}
exports.hasFlag = hasFlag;
function pad(str, max) {
    str = str.toString();
    return str.length < max ? pad("0" + str, max) : str;
}
