"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Provides ability to snapshot and revert state of Ethereum VM
 */
class Reverter {
    constructor(web3) {
        this.web3 = web3;
        this.snapshotId = 0;
    }
    revert(done, id) {
        const toSnapshotId = id !== undefined ? id : this.snapshotId;
        this.web3.currentProvider.sendAsync({
            jsonrpc: "2.0",
            method: "evm_revert",
            id: new Date().getTime(),
            params: [toSnapshotId]
        }, (err, result) => {
            if (err) {
                done(err);
            }
            else {
                this.snapshot(done);
            }
        });
    }
    snapshot(done) {
        this.web3.currentProvider.sendAsync({
            jsonrpc: "2.0",
            method: "evm_snapshot",
            id: new Date().getTime(),
            params: []
        }, (err, result) => {
            if (err) {
                done(err);
            }
            else {
                this.snapshotId = this.web3.toDecimal(result.result);
                done();
            }
        });
    }
    promisifyRevert(id) {
        return new Promise((resolve, reject) => {
            this.revert(err => {
                if (err) {
                    return reject(err);
                }
                resolve();
            }, id);
        });
    }
    promisifySnapshot() {
        return new Promise((resolve, reject) => {
            this.snapshot(err => {
                if (err) {
                    return reject(err);
                }
                resolve();
            });
        });
    }
}
exports.Reverter = Reverter;
