/**
 *  Usage:
 *    let timeMachine = new TimeMachine(web3);
 *    var clock; // Clock.sol instance
 *
 *    before('setup', function(done) {
 *      Clock.deployed()
 *        .then(_clock => clock = _clock)
 *        .then(() => done());
 *    });
 *
 *    it("Jump forward +500 sec", function() {
 *     return clock.time.call()
 *       .then(_time => initialTime = _time)
 *       .then(() => timeMachine.jump(500))
 *       .then(() => clock.time.call())
 *       .then(_time => assert.isTrue(_time - initialTime >= 500));
 *    });
 *
 *    it("Jump forward +1 hour", function() {
 *     return clock.time.call()
 *       .then(_time => initialTime = _time)
 *       .then(() => {
 *           var currentDate = timeMachine.secondsToDate(initialTime);
 *           currentDate.setHours(currentDate.getHours() + 1);
 *           return timeMachine.jump(currentDate.getTime() / 1000 - initialTime);
 *       })
 *       .then(() => clock.time.call())
 *       .then(_time => assert.isTrue(_time - initialTime >= 3600));
 *     });
 */
/// <reference types="types-web3" />
import Web3 from "web3";
declare type Web3Method = "evm_increaseTime" | "evm_mine";
/**
 * Allows to manipulate time in Ethereum VM.
 */
export declare class TimeMachine {
    readonly web3: Web3;
    dTime: number;
    constructor(web3: Web3);
    send(method: Web3Method, params: any[] | undefined, callback: (err?: any, result?: any) => void): void;
    jump(seconds: number): Promise<void>;
    secondsToDate(seconds: number): Date;
    reset(): Promise<void>;
}
export {};
