"use strict";
/**
 *  Usage:
 *    let timeMachine = new TimeMachine(web3);
 *    var clock; // Clock.sol instance
 *
 *    before('setup', function(done) {
 *      Clock.deployed()
 *        .then(_clock => clock = _clock)
 *        .then(() => done());
 *    });
 *
 *    it("Jump forward +500 sec", function() {
 *     return clock.time.call()
 *       .then(_time => initialTime = _time)
 *       .then(() => timeMachine.jump(500))
 *       .then(() => clock.time.call())
 *       .then(_time => assert.isTrue(_time - initialTime >= 500));
 *    });
 *
 *    it("Jump forward +1 hour", function() {
 *     return clock.time.call()
 *       .then(_time => initialTime = _time)
 *       .then(() => {
 *           var currentDate = timeMachine.secondsToDate(initialTime);
 *           currentDate.setHours(currentDate.getHours() + 1);
 *           return timeMachine.jump(currentDate.getTime() / 1000 - initialTime);
 *       })
 *       .then(() => clock.time.call())
 *       .then(_time => assert.isTrue(_time - initialTime >= 3600));
 *     });
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Allows to manipulate time in Ethereum VM.
 */
class TimeMachine {
    constructor(web3) {
        this.web3 = web3;
        this.dTime = 0;
    }
    send(method, params = [], callback) {
        this.web3.currentProvider.sendAsync({
            jsonrpc: "2.0",
            method,
            params: params || [],
            id: new Date().getTime()
        }, callback);
    }
    jump(seconds) {
        return new Promise((resolve, reject) => {
            this.send("evm_increaseTime", [seconds], (e, result) => {
                if (e)
                    reject(e);
                this.dTime += seconds;
                // Mine a block so new time is recorded.
                this.send("evm_mine", [], (err, result) => {
                    if (e)
                        reject(e);
                    this.web3.eth.getBlock("latest", (e, block) => {
                        if (e)
                            reject(e);
                        resolve();
                    });
                });
            });
        });
    }
    secondsToDate(seconds) {
        const t = new Date(Date.UTC(1970, 0, 1));
        t.setSeconds(seconds);
        return t;
    }
    reset() {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO: negative values are not suported yet
            yield this.jump(-this.dTime);
            this.dTime = 0;
        });
    }
}
exports.TimeMachine = TimeMachine;
